@@ -23,6 +23,27 @@ class ContactHandler:
 			cp = c.get_property('other-phone')
 			self.phonedict[c.get_name()] = (mb, cp)
 	
+	""" returns all the numbers from a name, as a list """
+	def get_numbers_from_name(self, name):
+		search = self.ab.search(name)
+		res = search[0]
+		props = ['assistant-phone', 'business-phone', 'business-phone-2', 'callback-phone', 'car-phone', 'company-phone', 'home-phone', 'home-phone-2', 'mobile-phone', 'other-phone', 'primary-phone']
+		nrlist = []
+		for p in props:
+			nr = res.get_property(p)
+			if nr != None:
+				nrlist.append(nr)
+		return nrlist
+		
+	
+	""" returns all contact names sorted by name """
+	def get_contacts_as_list(self):
+		retlist = []
+		for contact in self.contacts:
+			retlist.append(contact.get_name())
+		retlist.sort(key=str.lower)
+		return retlist
+	
 	""" takes a number on international format (ie +46730111111) """
 	def get_name_from_number(self, number):
 		### do some voodoo here
@@ -69,7 +90,9 @@ if __name__ == '__main__':
 	cb = ContactHandler()
 	phonedict = {}
 	
-	#print cb.get_name_from_number('+46')
+	#print cb.get_numbers_from_name('')
+	#asd = cb.get_contacts_as_list()
+	#print asd
 	
 	"""r = cb.ab.search('') # Returns List of results
 	print r
