@@ -20,7 +20,7 @@ if __name__ == '__main__':
 	len = os.stat(fname)[6]
 	data2 = array.array('B')
 	data2.read(f, len)
-	#print data2
+	print data2
 	data = []
 	for b in data2:
 		data.append(b)
@@ -30,8 +30,9 @@ if __name__ == '__main__':
 	#print data
 	#decoder = mms_pdu.MMSDecoder()
 	#wspdata = decoder.decodeData(data)
-	
-	message = MMSMessage.fromFile(fname)
+	decoder = mms_pdu.MMSDecoder()
+	message = decoder.decodeResponseHeader(data)
+	print message
 	
 	
 	
