@@ -61,8 +61,8 @@ class fMMS_GUI(hildon.Program):
 		textcell.set_property('xalign', 0.0)
 		
 		self.liststore = gtk.ListStore(gtk.gdk.Pixbuf, str, gtk.gdk.Pixbuf, str)
-		treeview = hildon.GtkTreeView(gtk.HILDON_UI_MODE_EDIT)
-		treeview.set_model(self.liststore)
+		self.treeview = hildon.GtkTreeView(gtk.HILDON_UI_MODE_EDIT)
+		self.treeview.set_model(self.liststore)
 
 		
 		icon_col = gtk.TreeViewColumn('Icon')
@@ -72,9 +72,9 @@ class fMMS_GUI(hildon.Program):
 		
 		self.add_buttons_liststore()
 		
-		treeview.append_column(icon_col)
-		treeview.append_column(sender_col)
-		treeview.append_column(placeholder_col)
+		self.treeview.append_column(icon_col)
+		self.treeview.append_column(sender_col)
+		self.treeview.append_column(placeholder_col)
 		
 		icon_col.pack_start(iconcell, False)
 		icon_col.set_attributes(iconcell, pixbuf=0)
@@ -83,12 +83,17 @@ class fMMS_GUI(hildon.Program):
 		placeholder_col.pack_end(photocell, False)
 		placeholder_col.set_attributes(photocell, pixbuf=2)
 		
-		selection = treeview.get_selection()
+		selection = self.treeview.get_selection()
 		#selection.set_mode(gtk.SELECTION_SINGLE)
-		treeview.connect('hildon-row-tapped', self.show_mms)
+		self.treeview.connect('hildon-row-tapped', self.show_mms)
 		
-		self.treeview = treeview
-		pan.add_with_viewport(treeview)
+		
+		self.liststore_menu = self.liststore_mms_menu()
+		self.treeview.tap_and_hold_setup(self.liststore_menu)
+		#treeview.connect('tap-and-hold', self.liststore_mms_clicked)
+		
+	
+		pan.add_with_viewport(self.treeview)
 		self.window.add(pan)
 	
 		self.menu = self.create_menu()
@@ -249,11 +254,12 @@ class fMMS_GUI(hildon.Program):
 		# Populate selector
 		i = 0
 		for apn in apnlist:
-			if apn == currval:
-				self.active_apn_index = i
-			i += 1	
-			# Add item to the column 
-			selector.append_text(apn)
+			if apn != None:
+				if apn == currval:
+					self.active_apn_index = i
+				i += 1	
+				# Add item to the column 
+				selector.append_text(apn)
 			
 		selector.center_on_selected()
 		selector.set_active(0, i)
@@ -324,9 +330,110 @@ class fMMS_GUI(hildon.Program):
 	""" lets call it quits! """
 	def quit(self, *args):
 		gtk.main_quit()
+		
+	""" delete push message """
+	def delete_push(self, fname):
+		fullpath = self._pushdir + fname
+		print fullpath
+		if os.path.isfile(fullpath):
+			print "removing", fullpath
+			try:
+				os.remove(fullpath)
+			except Exception, e:
+				raise
+		
+	
+	""" delete mms message (eg for redownload) """
+	def delete_mms(self, fname):
+		fullpath = self._mmsdir + fname
+		print fullpath
+		if os.path.isdir(fullpath):
+			print "starting deletion of", fullpath
+			filelist = self.getfiles(fullpath)
+			for fn in filelist:
+				try:
+					fullfn = fullpath + "/" + fn
+					os.remove(fullfn)
+				except:
+					print "failed to remove", fullfn
+			try:
+				print "trying to remove", fullpath
+				os.rmdir(fullpath)
+			except OSError, e:
+				print "failed to remove dir:", e, e.args
+				raise
+	
+	""" delete push & mms """
+	def delete_push_mms(self, fname):
+		try:
+			self.delete_push(fname)
+			self.delete_mms(fname)
+			banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Message deleted")
+		except Exception, e:
+			print "Exception caught:"
+			print e, e.args
+			banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Failed to delete message.")
+
+	""" action on delete contextmenu click """
+	def liststore_delete_clicked(self, widget):
+		dialog = gtk.Dialog()
+		dialog.set_title("Confirm")
+		dialog.add_button(gtk.STOCK_YES, 1)
+		dialog.add_button(gtk.STOCK_NO, 0)
+		label = gtk.Label("Are you sure you want to delete the message?")
+		dialog.vbox.add(label)
+		dialog.show_all()
+		ret = dialog.run()
+		if ret == 1:
+			(model, miter) = self.treeview.get_selection().get_selected()
+			# the 4th value is the filename (start counting at 0)
+			filename = model.get_value(miter, 3)
+			print "deleting", filename
+			self.delete_push_mms(filename)
+			self.liststore.remove(miter)
+		dialog.destroy()
+		return
+	
+	""" action on delete contextmenu click """
+	def liststore_redl_clicked(self, widget):
+		(model, miter) = self.treeview.get_selection().get_selected()
+		# the 4th value is the filename (start counting at 0)
+		filename = model.get_value(miter, 3)
+		print "redownloading", filename
+		try:
+			self.delete_mms(filename)
+			self._get_mms_from_push(self._pushdir + "/" + filename)
+			self.show_mms(self.treeview, model.get_path(miter))
+		except Exception, e:
+			print e, e.args
+			banner = hildon.hildon_banner_show_information(self.window, "", "fMMS: Operation failed")
+		hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
+
+	""" long press on image creates this """
+	def liststore_mms_menu(self):
+		menu = gtk.Menu()
+		menu.set_title("hildon-context-sensitive-menu")
+
+		redlItem = gtk.MenuItem("Redownload")
+		menu.append(redlItem)
+		redlItem.connect("activate", self.liststore_redl_clicked)
+		redlItem.show()
+		
+		separator = gtk.MenuItem()
+		menu.append(separator)
+		separator.show()
+		
+		openItem = gtk.MenuItem("Delete")
+		menu.append(openItem)
+		openItem.connect("activate", self.liststore_delete_clicked)
+		openItem.show()
+		
+		menu.show_all()
+		return menu
 
 	""" show the selected mms """		
 	def show_mms(self, treeview, path):
+		print path
 		model = treeview.get_model()
 		miter = model.get_iter(path)
 		# the 4th value is the filename (start counting at 0)
@@ -519,6 +626,8 @@ class fMMS_GUI(hildon.Program):
 		return pdict
 		
 	""" gets a mms from a previously received push """
+	""" this function requires the fname to be the fullpath """
+	# TODO: dont require fullpath
 	def _get_mms_from_push(self, fname):
 		plist = self._read_push_as_list(fname)
 
