@@ -14,6 +14,7 @@ import socket
 from wappushhandler import MMSSender
 import osso
 import fmms_config as fMMSconf
+import contacts as ContactH
 import Image
 import mimetypes
 import dbus
@@ -24,6 +25,7 @@ class fMMS_GUI(hildon.Program):
 		program = hildon.Program.get_instance()
 		
 		self.config = fMMSconf.fMMS_config()
+		self.ch = ContactH.ContactHandler()
 		
 		self.window = hildon.StackableWindow()
 		self.window.set_title("fMMS - New MMS")
@@ -46,6 +48,7 @@ class fMMS_GUI(hildon.Program):
 		topHBox1 = gtk.HBox()
 		
 		bTo = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "     To     ")
+		bTo.connect('clicked', self.open_contacts_dialog)
 		self.eNumber = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
 		
 		#topHBox.add(bTo)
@@ -93,10 +96,66 @@ class fMMS_GUI(hildon.Program):
 		allBox.pack_start(midHBox, True, True)
 		allBox.pack_start(botHBox, False, False)
 		
-		pan.add_with_viewport(allBox)
-		self.window.add(pan)
+		self.pan = pan
+		self.pan.add_with_viewport(allBox)
+		self.window.add(self.pan)
 		self.window.show_all()
 		self.add_window(self.window)
+	
+	# TODO: pass reference instead of making it available in the object?
+	def open_contacts_dialog(self, button):
+		selector = self.create_contacts_selector()
+		self.contacts_dialog = gtk.Dialog("Select a contact")
+
+		# TODO: remove hardcoded height
+		self.contacts_dialog.set_default_size(-1, 320)
+			        			    
+		self.contacts_dialog.vbox.pack_start(selector)
+		self.contacts_dialog.show_all()
+		ret = self.contacts_dialog.run()
+		self.contacts_dialog.destroy()
+		
+	def contact_number_chosen(self, button, nrdialog):
+		print button.get_label()
+		nr = button.get_label().replace(" ", "")
+		self.eNumber.set_text(nr)
+		nrdialog.response(0)
+		self.contacts_dialog.response(0)
+		
+	def contact_selector_changed(self, selector, data):
+		print data
+		username = selector.get_current_text()
+		nrlist = self.ch.get_numbers_from_name(username)
+		print nrlist
+		nrdialog = gtk.Dialog("Pick a number")
+		for number in nrlist:
+			button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+			button.set_label(number)
+			button.connect('clicked', self.contact_number_chosen, nrdialog)
+			nrdialog.vbox.pack_start(button)
+		nrdialog.show_all()
+		# this is blocking until we get a return
+		ret = nrdialog.run()
+		nrdialog.destroy()
+	
+	def create_contacts_selector(self):
+		#Create a HildonTouchSelector with a single text column
+		selector = hildon.TouchSelector(text = True)
+		selector.connect("changed", self.contact_selector_changed)
+
+		cl = self.ch.get_contacts_as_list()
+
+		# Populate selector
+		for contact in cl:
+			if contact != None:
+				# Add item to the column 
+				#print "adding", contact
+				selector.append_text(contact)
+
+		# Set selection mode to allow multiple selection
+		selector.set_column_selection_mode(hildon.TOUCH_SELECTOR_SELECTION_MODE_SINGLE)
+		return selector
+
 		
 	def open_file_dialog(self, button):
 		#fsm = hildon.FileSystemModel()
