@@ -150,6 +150,38 @@ class MMSDecoder(wsp_pdu.Decoder):
         self._mmsMessage.headers[header] = (value)
         return self._mmsMessage.headers
     
+    """ messy stuff """
+    # TODO: clean up
+    def decodeResponseHeader(self, data):
+		dataIter = PreviewIterator(data)
+		length = len(data)
+		headers = {}
+		eof = False
+		while 1:
+			try:
+				try:
+					byte = wsp_pdu.Decoder.decodeShortIntegerFromByte(dataIter.preview())
+				except StopIteration:
+					break
+				if byte in MMSEncodingAssignments.fieldNames:
+				    dataIter.next()
+				    mmsFieldName = MMSEncodingAssignments.fieldNames[byte][0]
+				else:
+				    dataIter.resetPreview()
+				    raise wsp_pdu.DecodeError, 'Invalid MMS Header: could not decode MMS field name'
+				try:
+				    #print MMSEncodingAssignments.fieldNames[byte][1]
+				    exec 'mmsValue = MMSDecoder.decode%s(dataIter)' % MMSEncodingAssignments.fieldNames[byte][1]
+				except wsp_pdu.DecodeError, msg:
+				    raise wsp_pdu.DecodeError, 'Invalid MMS Header: Could not decode MMS-value: %s' % msg
+				except:
+				    print 'A fatal error occurred, probably due to an unimplemented decoding operation. Tried to decode header: %s' % mmsFieldName
+				    raise
+			except wsp_pdu.DecodeError:
+				header, value = wsp_pdu.Decoder.decodeHeader(dataIter) #MMSDecoder.decodeApplicationHeader(byteIter)
+			headers[mmsFieldName] = mmsValue
+		return headers
+    
     def decodeMessageHeader(self):
         """ Decodes the (full) MMS header data
         
